lsfSleigh: sleigh Auxiliary Function
Description
This function will properly check to see if the R script
has been launched in a parallel fashion. If so, it will
start jobs on the provided nodes using SSH. If not, it expects
that the parameter 'N' contains the number of nodes to start
via 'bsub'. Extra arguments to bsub can be provided using the
lsfoptions parameter.