Learn R Programming

nws (version 1.7.0.0)

nws-package: The NetWorkSpaces Package

Description

NetWorkSpaces makes it easy to create and experiment with parallel programs without requiring specialized tools or hardware. You must install both the NetWorkSpaces server (on one machine) and the R NetWorkSpaces package (on all machines involved in the computation). The server is implemented using Python and Twisted (a Python package), which are required. To download and install the server, go to the R NetWorkSpaces project on Source Forge at http://sourceforge.net/projects/nws-r.

A commercial version of NetWorkSpaces which has additional fault tolerance features is available as part of REvolution Computing's ParallelR product. More information is available at http://www.revolution-computing.com/revolution/web/static/products.

Arguments

Details

Further information is available in the following help topics: ll{ sleigh Create a sleigh for parallel execution eachWorker Execute a function on each of the workers in the sleigh eachElem Execute a function for a set of arguments netWorkSpace Create a NetWorkSpace nwsStore Assign a value to a variable in a NetWorkSpace nwsFetch Consume a value from a variable in a NetWorkSpace nwsFind Retrieve but don't consume a value from a variable in a NetWorkSpace }

For a complete list of functions with individual help pages, use library(help="nws").