Learn R Programming

nws (version 1.6.2)

nwsListVars: netWorkSpace Class Method

Description

List variables in a netWorkSpace.

Usage

## S3 method for class 'netWorkSpace':
nwsListVars(.Object, wsName='', showDataFrame=FALSE)

Arguments

.Object
a netWorkSpace class object
wsName
name of the netWorkSpace
showDataFrame
show result in data frame or string

Details

Return listing of variables in the netWorkSpace with the name passed by wsName argument. If wsName is empty, then return variables in the netWorkSpace represented by .Object.

The return values from nwsListVars can be represented in a string or a data frame. If showDataFrame is set to FALSE (default value), then the listing is returned in a string. To see list output clearly, use: write(nwsListVars(.Object), stdout()). If showDataFrame is set to TRUE, then the listing is returned in a data frame with these fields: Variables, NumValues, NumFetchers, NumFinders, and Mode.

Examples

Run this code
# example 1
ws <- netWorkSpace('nws example')
write(nwsListVars(ws), stdout())

Run the code above in your browser using DataLab