A commercial version of NetWorkSpaces which has additional fault
tolerance features is available as part of REvolution Computing's
ParallelR product. More information is
available at
sleigh Create a sleigh for parallel execution
eachWorker Execute a function on each of the workers
in the sleigh
eachElem Execute a function for a set of arguments
netWorkSpace Create a NetWorkSpace
nwsStore Assign a value to a variable in a NetWorkSpace
nwsFetch Consume a value from a variable in a NetWorkSpace
nwsFind Retrieve but don't consume a value from a variable in
a NetWorkSpace
}For a complete list of functions with individual help pages,
use library(help="nws").